==> ros-lunar-nerian-stereo_2.1.0.orig.tar.gz: nerian-vision-software-5_0_1-src/libvisiontransfer/examples/asynctransfer_example.cpp <==
/*******************************************************************************
 * Copyright (c) 2017 Nerian Vision Technologies
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *******************************************************************************/

#include <visiontransfer/asynctransfer.h>
#include <visiontransfer/imagepair.h>
#include <iostream>
#include <exception>
#include <stdio.h>

#ifdef _MSC_VER
// Visual studio does not come with snprintf
#define snprintf _snprintf_s
#endif

int main() {
    try {
        // Create an async transfer object that receives data from
        // SP1 or SceneScan on the default port using UDP
        AsyncTransfer asyncTransfer(ImageTransfer::UDP, NULL, NULL,
            NULL, "7681");

        // Receive 100 images
        for(int i=0; i<100; i++) {
            std::cout << "Receiving image " << i << std::endl;

            // Receive image
            ImagePair imagePair;
            while(!asyncTransfer.collectReceivedImagePair(imagePair,
                0.1 /*timeout*/)) {
                // Keep on trying until reception is successful
            }

            // Write both images one after another
            for(int imageNumber = 0; imageNumber <=1; imageNumber++) {
                // Create PGM file
                char fileName[100];
                snprintf(fileName, sizeof(fileName), "image%03d_%d.pgm", i,
                    imageNumber);

                imagePair.writePgmFile(imageNumber, fileName);
            }
        }
    } catch(const std::exception& ex) {
        std::cerr << "Exception occurred: " << ex.what() << std::endl;
    }

    return 0;
}

==> ros-lunar-nerian-stereo_3.4.0.orig.tar.gz: nerian-vision-software-6_5_0-src/libvisiontransfer/examples/asynctransfer_example.cpp <==
/*******************************************************************************
 * Copyright (c) 2019 Nerian Vision GmbH
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *******************************************************************************/

#include <visiontransfer/deviceenumeration.h>
#include <visiontransfer/asynctransfer.h>
#include <visiontransfer/imagepair.h>
#include <iostream>
#include <exception>
#include <stdio.h>

#ifdef _MSC_VER
// Visual studio does not come with snprintf
#define snprintf _snprintf_s
#endif

using namespace visiontransfer;

int main() {
    try {
        // Search for SceneScan devices
        DeviceEnumeration deviceEnum;
        DeviceEnumeration::DeviceList devices = deviceEnum.discoverDevices();
        if(devices.size() == 0) {
            std::cout << "No devices discovered!" << std::endl;
            return -1;
        }

        // Print devices
        std::cout << "Discovered devices:" << std::endl;
        for(unsigned int i = 0; i< devices.size(); i++) {
            std::cout << devices[i].toString() << std::endl;
        }
        std::cout << std::endl;

        // Create an image transfer object that receives data from
        // the first detected SceneScan
        AsyncTransfer asyncTransfer(devices[0]);

        // Receive 100 images
        for(int i=0; i<100; i++) {
            std::cout << "Receiving image " << i << std::endl;

            // Receive image
            ImagePair imagePair;
            while(!asyncTransfer.collectReceivedImagePair(imagePair,
                0.1 /*timeout*/)) {
                // Keep on trying until reception is successful
            }

            // Write both images one after another
            for(int imageNumber = 0; imageNumber <=1; imageNumber++) {
                // Create PGM file
                char fileName[100];
                snprintf(fileName, sizeof(fileName), "image%03d_%d.pgm", i,
                    imageNumber);

                imagePair.writePgmFile(imageNumber, fileName);
            }
        }
    } catch(const std::exception& ex) {
        std::cerr << "Exception occurred: " << ex.what() << std::endl;
    }

    return 0;
}
